@@ -1,6 +1,6 @@
 """ View """
 
-from textflow.view import about, annotate, errors, index, login, project, dashboard, user
+from textflow.view import about, annotate, errors, index, login, project, dashboard, user, base
 
 __all__ = [
     about,
